@@ -1,17 +1,18 @@
 package org.gcube.applicationsupportlayer.social;
 
+import java.net.URL;
 import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.List;
 import java.util.Set;
 import java.util.UUID;
 
+import org.gcube.applicationsupportlayer.social.ex.UnsupportedNotificationException;
 import org.gcube.applicationsupportlayer.social.mailing.EmailPlugin;
+import org.gcube.applicationsupportlayer.social.shared.SocialFileItem;
 import org.gcube.applicationsupportlayer.social.shared.SocialNetworkingSite;
 import org.gcube.applicationsupportlayer.social.shared.SocialNetworkingUser;
-import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
-import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
-import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
+import org.gcube.applicationsupportlayer.social.shared.SocialSharedFolder;
 import org.gcube.portal.databook.shared.Notification;
 import org.gcube.portal.databook.shared.NotificationChannelType;
 import org.gcube.portal.databook.shared.NotificationType;
@@ -41,6 +42,8 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	public static final String USER_MESSAGES_FRIENDLY_URL = "/messages";
 	public static final String USER_NOTIFICATION_FRIENDLY_URL = "/notifications";
 
+	private final int MAX_TRIAL = 10;
+
 	private String portalName;
 	private String senderEmail;
 	private String portalURL;
@@ -203,27 +206,26 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @return .
 	 */
 	private String getApplicationUrl() {
-		if (applicationProfile != null && applicationProfile.getUrl() != null) {
-			_log.trace("getApplicationUrl="+applicationProfile.getUrl());
-			return applicationProfile.getUrl();			
-		}
-		else {
-			_log.warn("applicationProfile NULL or url is empty returning " + siteLandingPagePath);
-			return siteLandingPagePath;
+		int count = 0;
+		while (count < MAX_TRIAL){
+			if (applicationProfile != null && applicationProfile.getUrl() != null) {
+				_log.trace("getApplicationUrl="+applicationProfile.getUrl());
+				return applicationProfile.getUrl();			
+			}
+			if (applicationProfile != null && applicationProfile.getKey() != null) 
+				applicationProfile =  getProfileFromInfrastrucure(applicationProfile.getKey());
+			count++;
 		}
+		_log.warn("applicationProfile NULL or url is empty returning " + siteLandingPagePath);
+		return siteLandingPagePath;
 	}
 	/**
 	 * {@inheritDoc}
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyFolderSharing(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
-		String sharedFolderName = sharedFolder.getName();
-		if (sharedFolder.isShared()) {
-			WorkspaceSharedFolder sharedWSFolder = (WorkspaceSharedFolder) sharedFolder;
-			if (sharedWSFolder.isVreFolder())
-				sharedFolderName = sharedWSFolder.getDisplayName(); 
-		}
+	public boolean notifyFolderSharing(String userIdToNotify, SocialSharedFolder sharedFolder) {
+		String sharedFolderName = sharedFolder.isVreFolder()?sharedFolder.getDisplayName():sharedFolder.getTitle();
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_FOLDER_SHARE, 
@@ -260,13 +262,14 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 
 		return saveNotification(not);
 	}
+	
 	/**
 	 * {@inheritDoc}
 	 * @throws Exception 
 	 */
 	@Override
-	public boolean notifyAdministratorUpgrade(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception {
-		String sharedFolderName = sharedFolder.getName();
+	public boolean notifyAdministratorUpgrade(String userIdToNotify, SocialSharedFolder sharedFolder) throws Exception {
+		String sharedFolderName = sharedFolder.getTitle();
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ADMIN_UPGRADE, 
@@ -282,13 +285,14 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 
 		return saveNotification(not);
 	}
+
 	/**
 	 * {@inheritDoc}
 	 * @throws Exception 
 	 */
 	@Override
-	public boolean notifyAdministratorDowngrade(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws Exception {
-		String sharedFolderName = sharedFolder.getName();
+	public boolean notifyAdministratorDowngrade(String userIdToNotify, SocialSharedFolder sharedFolder) throws Exception {
+		String sharedFolderName = sharedFolder.getTitle();
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ADMIN_DOWNGRADE, 
@@ -310,7 +314,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyFolderRenaming(String userIdToNotify, String previousName, String newName, String renamedFolderId) throws InternalErrorException {
+	public boolean notifyFolderRenaming(String userIdToNotify, String previousName, String newName, String renamedFolderId) {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_FOLDER_RENAMED, 
@@ -327,29 +331,11 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 		return saveNotification(not);
 	}
 	/**
-	 * {@inheritDoc}
-	 * @throws UserManagementPortalException 
-	 * @throws UserRetrievalFault 
-	 * @throws UserManagementSystemException 
+	 * @Deprecated
 	 */
-	@Override
-	public boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceSharedFolder sharedFolder, String newAddedUserId) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
-		UserManager um = new LiferayUserManager();
-		GCubeUser user = um.getUserByUsername(newAddedUserId);
-		Notification not = new Notification(
-				UUID.randomUUID().toString(), 
-				NotificationType.WP_FOLDER_ADDEDUSER, 
-				userIdToNotify, //user no notify
-				sharedFolder.getId(),  //the 
-				new Date(),
-				siteLandingPagePath + USER_WORKSPACE_FRIENDLY_URL +"?itemid="+sharedFolder.getId(),
-				"added "+ user.getFullname() +" to your workspace shared folder \""+ sharedFolder.getName()+"\"",
-				false, 
-				currUser.getUsername(),
-				currUser.getFullname(), 
-				currUser.getUserAvatarId());
-
-		return saveNotification(not);
+	@Deprecated
+	public boolean notifyFolderAddedUser(String userIdToNotify, SocialSharedFolder sharedFolder, String newAddedUserId) throws UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
+		return notifyFolderAddedUser(userIdToNotify, sharedFolder, newAddedUserId, new LiferayUserManager());
 	}
 	/**
 	 * {@inheritDoc}
@@ -358,12 +344,43 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws UserManagementSystemException 
 	 */
 	@Override
-	public boolean notifyFolderAddedUsers(String userIdToNotify, WorkspaceSharedFolder sharedFolder, List<String> newAddedUserIds) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException  {
+	public boolean notifyFolderAddedUser(String userIdToNotify, SocialSharedFolder sharedFolder, String newAddedUserId, UserManager um) throws UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
+		GCubeUser user = um.getUserByUsername(newAddedUserId);
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.WP_FOLDER_ADDEDUSER, 
+				userIdToNotify, //user no notify
+				sharedFolder.getId(),  //the 
+				new Date(),
+				siteLandingPagePath + USER_WORKSPACE_FRIENDLY_URL +"?itemid="+sharedFolder.getId(),
+				"added "+ user.getFullname() +" to your workspace shared folder \""+ sharedFolder.getTitle()+"\"",
+				false, 
+				currUser.getUsername(),
+				currUser.getFullname(), 
+				currUser.getUserAvatarId());
+
+		return saveNotification(not);
+	}
+	/**
+	 * @Deprecated
+	 */
+	@Deprecated
+	public boolean notifyFolderAddedUsers(String userIdToNotify, SocialSharedFolder sharedFolder, List<String> newAddedUserIds) throws UserManagementSystemException, UserRetrievalFault, UserManagementPortalException  {
+			return notifyFolderAddedUsers(userIdToNotify, sharedFolder, newAddedUserIds, new LiferayUserManager());
+		}
+
+	/**
+	 * {@inheritDoc}
+	 * @throws UserManagementPortalException 
+	 * @throws UserRetrievalFault 
+	 * @throws UserManagementSystemException 
+	 */
+	@Override
+	public boolean notifyFolderAddedUsers(String userIdToNotify, SocialSharedFolder sharedFolder, List<String> newAddedUserIds,  UserManager um) throws UserManagementSystemException, UserRetrievalFault, UserManagementPortalException  {
 		if (newAddedUserIds != null && newAddedUserIds.size() > 0) {
 			if (newAddedUserIds.size() == 1)
-				return notifyFolderAddedUser(userIdToNotify, sharedFolder, newAddedUserIds.get(0));
+				return notifyFolderAddedUser(userIdToNotify, sharedFolder, newAddedUserIds.get(0), um);
 			StringBuilder addedUsersFullNames = new StringBuilder();
-			UserManager um = new LiferayUserManager();
 			for (String userId : newAddedUserIds) 
 				addedUsersFullNames.append(um.getUserByUsername(userId).getFullname()).append(" ");
 
@@ -374,7 +391,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 					sharedFolder.getId(),  //the 
 					new Date(),
 					siteLandingPagePath + USER_WORKSPACE_FRIENDLY_URL +"?itemid="+sharedFolder.getId(),
-					"added "+ addedUsersFullNames +" to your workspace shared folder \""+ sharedFolder.getName()+"\"",
+					"added "+ addedUsersFullNames +" to your workspace shared folder \""+ sharedFolder.getTitle()+"\"",
 					false, 
 					currUser.getUsername(),
 					currUser.getFullname(), 
@@ -389,7 +406,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceSharedFolder sharedFolder) throws InternalErrorException, UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
+	public boolean notifyFolderRemovedUser(String userIdToNotify, SocialSharedFolder sharedFolder) throws  UserManagementSystemException, UserRetrievalFault, UserManagementPortalException {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_FOLDER_REMOVEDUSER, 
@@ -397,7 +414,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				sharedFolder.getId(),  //the 
 				new Date(),
 				siteLandingPagePath + USER_WORKSPACE_FRIENDLY_URL +"?itemid="+sharedFolder.getId(), 
-				"unshared his shared folder \""+ sharedFolder.getName() + "\" from your workspace",
+				"unshared his shared folder \""+ sharedFolder.getTitle() + "\" from your workspace",
 				false, 
 				currUser.getUsername(),
 				currUser.getFullname(), 
@@ -410,10 +427,10 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyAddedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyAddedItem(String userIdToNotify, SocialFileItem item, SocialSharedFolder sharedFolder) {
 		String notifyText = sharedFolder.isVreFolder() ? 
-				"added "+ item.getName() +" to the workspace group folder " + sharedFolder.getDisplayName() :
-					"added "+ item.getName() +" to your workspace shared folder "+ item.getPath().substring(0,item.getPath().lastIndexOf('/'));
+				"added "+ item.getTitle() +" to the workspace group folder " + sharedFolder.getDisplayName() :
+					"added "+ item.getTitle() +" to your workspace shared folder "+ sharedFolder.getTitle();
 
 				Notification not = new Notification(
 						UUID.randomUUID().toString(), 
@@ -435,9 +452,9 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyMovedItem(String userIdToNotify, WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyMovedItem(String userIdToNotify, SocialFileItem item, SocialSharedFolder sharedFolder) {
 		String notifyText = sharedFolder.isVreFolder() ? "removed item  "+ item.getName() +" from the workspace group folder " + sharedFolder.getDisplayName():
-			"removed item "+ item.getName() +" from your workspace shared folder \""+ sharedFolder.getName()+"\"";
+			"removed item "+ item.getName() +" from your workspace shared folder \""+ sharedFolder.getTitle()+"\"";
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
@@ -459,9 +476,9 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyRemovedItem(String userIdToNotify, String itemName, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyRemovedItem(String userIdToNotify, String itemName, SocialSharedFolder sharedFolder) {
 		String notifyText = sharedFolder.isVreFolder() ? "deleted item  \""+ itemName +"\" from the workspace group folder " + sharedFolder.getDisplayName():
-			" deleted item \""+ itemName +"\" from your workspace shared folder \""+ sharedFolder.getName()+"\"";
+			" deleted item \""+ itemName +"\" from your workspace shared folder \""+ sharedFolder.getTitle()+"\"";
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
@@ -483,9 +500,9 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyUpdatedItem(String userIdToNotify,	WorkspaceItem item, WorkspaceSharedFolder sharedFolder) throws InternalErrorException {
-		String notifyText = sharedFolder.isVreFolder() ? " updated  \""+ item.getName() +"\" from the workspace group folder \"" + sharedFolder.getDisplayName()+"\"":
-			" updated \""+ item.getName() +"\" to your workspace shared folder \""+ item.getPath().substring(0,item.getPath().lastIndexOf('/'))+"\"";
+	public boolean notifyUpdatedItem(String userIdToNotify,	SocialFileItem item, SocialSharedFolder sharedFolder) {
+		String notifyText = sharedFolder.isVreFolder() ? " updated  \""+ item.getName() +"\" from the workspace VRE folder \"" + sharedFolder.getDisplayName()+"\"":
+			" updated \""+ item.getName() +"\" to your workspace shared folder \""+ sharedFolder.getTitle() +"\"";
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
@@ -507,9 +524,9 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyItemRenaming(String userIdToNotify, String previousName, WorkspaceItem renamedItem,  WorkspaceSharedFolder rootSharedFolder) throws InternalErrorException {
-		String notifyText = rootSharedFolder.isVreFolder() ? "renamed \""+ previousName +"\" as \"" + renamedItem.getName() +"\" in the workspace group folder " + rootSharedFolder.getDisplayName():
-			"renamed \"" + previousName +"\" as \"" + renamedItem.getName() +"\" in your shared folder \"" + renamedItem.getPath().substring(0, renamedItem.getPath().lastIndexOf('/'))+"\"";
+	public boolean notifyItemRenaming(String userIdToNotify, String previousName, SocialFileItem renamedItem, SocialSharedFolder rootSharedFolder) {
+		String notifyText = rootSharedFolder.isVreFolder() ? "renamed \""+ previousName +"\" as \"" + renamedItem.getName() +"\" in the workspace VRE folder " + rootSharedFolder.getDisplayName():
+			"renamed \"" + previousName +"\" as \"" + renamedItem.getName() +"\" in your shared folder \"" + rootSharedFolder.getTitle()+"\"";
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
@@ -564,19 +581,19 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyPost(String userIdToNotify, String feedid,	String feedText, String ... hashtags) {
+	public boolean notifyPost(String userIdToNotify, String postId,	String postText, String ... hashtags) {
 		StringBuilder notificationText = new StringBuilder();
 		notificationText.append("posted on <b> ").append(currGroupName).append(":</b>") // has done something
-		.append("<br /><br /> ").append(feedText).append(" ")
+		.append("<br /><br /> ").append(postText).append(" ")
 		.append("<br /><br />");
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.POST_ALERT, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				notificationText.toString(),
 				false, 
 				currUser.getUsername(),
@@ -586,21 +603,21 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	}
 	
 	@Override
-	public boolean notifyPost(String userIdToNotify, String feedid,
-			String feedText, Set<String> mentionedVREGroups,
+	public boolean notifyPost(String userIdToNotify, String postId,
+			String postText, Set<String> mentionedVREGroups,
 			Set<String> hashtags) {
 		StringBuilder notificationText = new StringBuilder();
 		notificationText.append("posted on <b> ").append(currGroupName).append(":</b>") // has done something
-		.append("<br /><br /> ").append(feedText).append(" ")
+		.append("<br /><br /> ").append(postText).append(" ")
 		.append("<br /><br />");
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.POST_ALERT, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				notificationText.toString(),
 				false, 
 				currUser.getUsername(),
@@ -613,18 +630,18 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyOwnCommentReply(String userIdToNotify, String feedid, String feedText, String commentKey) {
+	public boolean notifyOwnCommentReply(String userIdToNotify, String postId, String postText, String commentKey) {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.OWN_COMMENT, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				"commented on your post: " 
 						+ "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
 						+ "border-left: 3px solid #ccc; font-style: italic;\">\""
-						+ feedText +"\"</div>",
+						+ postText +"\"</div>",
 						false, 
 						currUser.getUsername(),
 						currUser.getFullname(), 
@@ -636,7 +653,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyCommentReply(String userIdToNotify, String feedid, String commentText, String feedOwnerFullName, String feedOwnerId, String commentKey) {
+	public boolean notifyCommentReply(String userIdToNotify, String postId, String commentText, String feedOwnerFullName, String feedOwnerId, String commentKey) {
 		String notificationText =  (currUser.getUsername().compareTo(feedOwnerId) == 0) ? 
 				"also commented on his post: "  
 				+ "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  border-left: 3px solid #ccc; font-style: italic;\">\""
@@ -649,9 +666,9 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				UUID.randomUUID().toString(), 
 				NotificationType.COMMENT, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				notificationText,
 				false, 
 				currUser.getUsername(),
@@ -664,21 +681,21 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyCommentOnFavorite(String userIdToNotify, String feedid, String commentText, String commentKey) {
-		return notifyCommentOnLike(userIdToNotify, feedid, commentText, commentKey);
+	public boolean notifyCommentOnFavorite(String userIdToNotify, String postId, String commentText, String commentKey) {
+		return notifyCommentOnLike(userIdToNotify, postId, commentText, commentKey);
 	}
 	/**
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyCommentOnLike(String userIdToNotify, String feedid, String commentText, String commentKey) {
+	public boolean notifyCommentOnLike(String userIdToNotify, String postId, String commentText, String commentKey) {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.COMMENT, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				"commented on one of your liked posts: " 
 						+ "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  border-left: 3px solid #ccc; font-style: italic;\">\""
 						+ commentText +"\"</div>",
@@ -693,16 +710,16 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyUserTag(String userIdToNotify, String feedid, String feedText, String commentKey) {
+	public boolean notifyUserTag(String userIdToNotify, String postId, String postText, String commentKey) {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.MENTION, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				"mentioned you: " + "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  border-left: 3px solid #ccc; font-style: italic;\">\""
-						+ feedText +"\"</div>",
+						+ postText +"\"</div>",
 						false, 
 						currUser.getUsername(),
 						currUser.getFullname(), 
@@ -714,15 +731,23 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean notifyLikedFeed(String userIdToNotify, String feedid, String feedText) {
+	@Deprecated
+	public boolean notifyLikedFeed(String userIdToNotify, String postId, String postText) {
+		return notifyLikedPost(userIdToNotify, postId, postText);
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public boolean notifyLikedPost(String userIdToNotify, String postId, String postText) {
 
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.LIKE, 
 				userIdToNotify, //user no notify
-				feedid,  //the post 
+				postId,  //the post 
 				new Date(),
-				getApplicationUrl()+"?oid="+feedid, 
+				getApplicationUrl()+"?oid="+postId, 
 				"liked/subscribed to one of your post",
 				false, 
 				currUser.getUsername(),
@@ -812,7 +837,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
+	@Deprecated
 	public boolean notifyNewCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
 		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
 
@@ -846,7 +871,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
+	@Deprecated
 	public boolean notifyEditedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
 		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
 
@@ -879,7 +904,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
+	@Deprecated
 	public boolean notifyDeletedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate) {
 		SimpleDateFormat spf = new SimpleDateFormat("EEE dd MMMMM, yyyy");
 
@@ -912,7 +937,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
+	@Deprecated
 	public boolean notifyTDMTabularResourceSharing(String userIdToNotify, String tabularResourceName, String encodedTabularResourceParams) throws Exception {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
@@ -932,7 +957,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
+	@Deprecated
 	public boolean notifyTDMObjectSharing(String userIdToNotify, NotificationType type, String tdmObjectName, String encodedTabularResourceParams) throws Exception {
 		if  (! (type == NotificationType.TDM_RULE_SHARE || type ==  NotificationType.TDM_TEMPLATE_SHARE))
 			throw new IllegalArgumentException("Type must be either TDM_RULE_SHARE or TDM_TEMPLATE_SHARE");
@@ -960,4 +985,27 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 
 		return saveNotification(not);
 	}
+
+	@Override
+	public boolean notifyCatalogueEvent(NotificationType type, String userIdToNotify, String itemId, String notifyText, URL url) throws Exception {
+		final String prefix = "CAT_";
+		if (! type.toString().startsWith(prefix)) {
+			throw new UnsupportedNotificationException("The type of notification is not belonging to the catalogue ones, must start with " + prefix);
+		}
+
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				type, 
+				userIdToNotify, //user no notify
+				itemId,  //the 
+				new Date(),
+				url.toString(), 
+				notifyText,
+				false, 
+				currUser.getUsername(),
+				currUser.getFullname(), 
+				currUser.getUserAvatarId());
+
+		return saveNotification(not);
+	}
 }
