@@ -2,8 +2,13 @@ package org.gcube.applicationsupportlayer.social.mailing;
 
 import java.text.Format;
 import java.text.SimpleDateFormat;
+import java.util.Arrays;
+import java.util.Base64;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 
+import org.gcube.applicationsupportlayer.social.ApplicationNotificationsManager;
 import org.gcube.common.portal.GCubePortalConstants;
 import org.gcube.portal.databook.shared.Comment;
 import org.gcube.portal.databook.shared.Feed;
@@ -40,7 +45,7 @@ public class SocialMailingUtil {
 	 * @param hashtags
 	 * @return
 	 */
-	protected static String getHTMLEmail(Notification notification2Save, 
+	protected static String getHTMLEmail(String vreName, Notification notification2Save, 
 			String userFirstName, 
 			String portalURL, 
 			String siteLandingPagePath, 
@@ -50,18 +55,19 @@ public class SocialMailingUtil {
 			String commentKey,
 			String ... hashtags) {
 		String removedMarkup = notification2Save.getDescription().replaceAll("&amp;", "&");
-		if (hashtags != null && hashtags.length > 0) {
-			_log.debug("editing hyperlinks for mail client");
-			//notification2Save uri contains the absoulte path to the feed in the correct channel, e.g. /group/ustore_vre?oid=f1637958-34d0-48fc-b5ad-13b1116e389d
-			String pathToVRE = siteLandingPagePath + "?";
+
+		//notification2Save uri contains the absoulte path to the feed in the correct channel, e.g. /group/ustore_vre?oid=f1637958-34d0-48fc-b5ad-13b1116e389d		
+		String pathToVRE = siteLandingPagePath + "?";
+		if (notification2Save.getUri() != null) {
 			if (notification2Save.getUri().split("\\?").length > 0) {
 				pathToVRE = notification2Save.getUri().split("\\?")[0];
-			}					
-			removedMarkup = removedMarkup.replace("href=\"?", "href=\""+portalURL + pathToVRE + "?"); //because there is no indication of the portal		
+			}
 		}
+		_log.debug("editing hyperlinks for mail client");
+		removedMarkup = removedMarkup.replaceAll("href=\"/group/", "href=\""+portalURL + "/group/"); //because there is no indication of the portal (for mentions)		
+		removedMarkup = removedMarkup.replace("href=\"?", "href=\""+portalURL + pathToVRE + "?"); //because there is no indication of the portal (for hashtags)		
 
 		String sender = notification2Save.getSenderFullName();
-	
 		String portalHost = portalURL.replaceAll("https://", "");
 		portalHost = portalHost.replaceAll("http://", "");
 
@@ -74,8 +80,6 @@ public class SocialMailingUtil {
 				notification2Save.getType() == NotificationType.MENTION || 
 				notification2Save.getType() == NotificationType.OWN_COMMENT) {
 			body.append("<div>").append(WRITE_ABOVE_TO_REPLY).append("</div><br />");
-
-
 		}
 
 		String attachmentsNotice = "";
@@ -85,12 +89,14 @@ public class SocialMailingUtil {
 			attachmentsNotice = "<br/><p>Please note that email replies do not support attachments.</p>";
 		}
 
+		String userProfileLink = new StringBuffer(getVREUrl(portalURL, vreName))
+				.append("/").append(getUserProfileLink(notification2Save.getSenderid())).toString();
+
 		body.append("<div style=\"color:#000; font-size:13px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif;\">")
-		.append("Dear ").append(userFirstName).append(",")  //dear <user>
-		.append("<p>").append(sender).append(" ").append(removedMarkup) // has done something
+		.append("<p><a href=\"").append(userProfileLink).append("\">").append(sender).append("</a> ").append(removedMarkup) // has done something
 		.append(getActionLink(notification2Save, portalURL)) //Goto
 		.append(attachmentsNotice)
-		.append(SocialMailingUtil.buildHtmlDiscussion(notification2Save, feed, comments, commentKey)) // the original discussion
+		.append(SocialMailingUtil.buildHtmlDiscussion(portalURL, pathToVRE, notification2Save, feed, comments, commentKey)) // the original discussion
 		.append("</p>")  
 		.append("</div><br/>")
 		.append("<p><div style=\"color:#999999; font-size:11px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif;\">")
@@ -100,18 +106,19 @@ public class SocialMailingUtil {
 		.append("<a href=\"").append(portalURL).append("\" style=\"color:#3B5998;text-decoration:none\" target=\"_blank\">").append(portalHost)
 		.append("</a>. ")
 		.append(" If you don't want to receive these emails in the future, please <a href=\"")
-		.append(portalURL).append(siteLandingPagePath).append(GCubePortalConstants.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true")
+		.append(portalURL).append(siteLandingPagePath).append(ApplicationNotificationsManager.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true")
 		.append("\" style=\"color:#3b5998;text-decoration:none\" target=\"_blank\">unsubscribe</a>.")
 		.append("</div></p>")
 		.append("<p><div style=\"color:#999999; font-size:10px; font-family:'lucida grande',tahoma,verdana,arial,sans-serif; padding-top:15px;\">")
 		.append("WARNING / LEGAL TEXT: This message is intended only for the use of the individual or entity to which it is addressed and may contain ")
 		.append("information which is privileged, confidential, proprietary, or exempt from disclosure under applicable law. If you are not the intended recipient or the person responsible for delivering the message to the intended recipient, you are strictly prohibited from disclosing, distributing, copying, or in any way using this message.")
-		.append("If you have received this communication in error, please notify the <sender> and destroy and delete any copies you may have received.")
+		.append("If you have received this communication in error, please notify the sender and destroy and delete any copies you may have received.")
 		.append("</div></p>")
 		.append("</body>");
 
 		return body.toString();
 	}
+
 	/**
 	 * 
 	 * @param notification2Save
@@ -145,7 +152,7 @@ public class SocialMailingUtil {
 			}
 		}
 		String sender = notification2Save.getSenderFullName();
-		
+
 		String portalHost = portalURL.replaceAll("https://", "");
 		portalHost = portalHost.replaceAll("http://", "");
 
@@ -177,7 +184,7 @@ public class SocialMailingUtil {
 		.append(" by ")
 		.append(portalHost)
 		.append(" If you don't want to receive these emails in the future, please unsubscribe here: ")
-		.append(portalURL).append(siteLandingPagePath).append(GCubePortalConstants.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true");
+		.append(portalURL).append(siteLandingPagePath).append(ApplicationNotificationsManager.USER_NOTIFICATION_FRIENDLY_URL).append("?showsettings=true");
 
 		return body.toString();
 
@@ -193,16 +200,16 @@ public class SocialMailingUtil {
 	 * @param vreName
 	 * @return
 	 */
-	protected static String getSubjectByNotificationType(Notification notification2Save, String vreName, String userFirstName, String ...optionalParams) {		
+	protected static String getSubjectByNotificationType(Notification notification2Save, String vreName, String userFirstName, Set<String> mentionedVReGroups, String ...optionalParams) {		
 		switch (notification2Save.getType()) {
 		case LIKE:
-			return notification2Save.getSenderFullName()+" favorited your post in " + (vreName == null? "" : vreName);
+			return notification2Save.getSenderFullName()+" liked your post in " + (vreName == null? "" : vreName);
 		case COMMENT:
 			return notification2Save.getSenderFullName()+" commented on the post in " + (vreName == null? "" : vreName);
 		case MESSAGE:
 			String messageSubject = (optionalParams != null && optionalParams.length > 0) ? 
 					optionalParams[0] : notification2Save.getSenderFullName()+" sent you a message";
-					return messageSubject;
+			return messageSubject;
 		case WP_FOLDER_ADDEDUSER:
 			return "New user in a shared folder";
 		case WP_FOLDER_REMOVEDUSER:
@@ -223,23 +230,37 @@ public class SocialMailingUtil {
 			return notification2Save.getSenderFullName()+ " updated an item in a shared folder";
 		case WP_ITEM_RENAMED:
 			return notification2Save.getSenderFullName()+ " renamed an item in a shared folder";
+		case WP_FOLDER_RENAMED:
+			return notification2Save.getSenderFullName()+ " renamed a folder shared with you";			
 		case OWN_COMMENT:
 			return notification2Save.getSenderFullName() + " commented on your post in " + (vreName == null? "" : vreName);
 		case MENTION:
 			return notification2Save.getSenderFullName() + " mentioned you in " + (vreName == null? "" : vreName);
 		case POST_ALERT: 
-			String toReturn = notification2Save.getSenderFullName() + " shared a news on " + vreName;
+			String toReturn = notification2Save.getSenderFullName() + " posted on " + vreName;
+			if(mentionedVReGroups != null && !mentionedVReGroups.isEmpty()){
+				for (String mentionedGroup : mentionedVReGroups) {
+					toReturn += " [" + mentionedGroup + "]";
+				}
+			}
 			if (optionalParams != null) { //in this case optionalParams are the hashtags
-				for (int i = 0; i < optionalParams.length; i++) 
-					toReturn += " " + optionalParams[i];	
+				Set<String> hashtags = new HashSet<String>(Arrays.asList(optionalParams));
+				for (String hashtag : hashtags) 
+					toReturn += " " + hashtag;	
 			}
 			return toReturn;
+		case CAT_ITEM_DELETE:
+		case CAT_ITEM_PUBLISHED:
+		case CAT_ITEM_REJECTED:
+		case CAT_ITEM_SUBMITTED:
+		case CAT_ITEM_UPDATED:
+			return "[D4Science Catalogue] " + notification2Save.getSubjectid();
 		case REQUEST_CONNECTION:
 			return "Connection request";
 		case JOB_COMPLETED_NOK:
-			return "Job Completed";
+			return notification2Save.getSubjectid() + "'s job status notification"; // i.e. Name of the job  + ...
 		case JOB_COMPLETED_OK:
-			return "Job Completed";
+			return notification2Save.getSubjectid() + "'s job status notification"; // i.e. Name of the job  + ...
 		case CALENDAR_ADDED_EVENT:
 			return vreName +": New event in a shared calendar";
 		case CALENDAR_UPDATED_EVENT:
@@ -270,49 +291,45 @@ public class SocialMailingUtil {
 
 		switch (notification2Save.getType()) {
 		case LIKE:		
-			actionLink.append("\">").append(" Open Post").append("</a>");
-			break;
 		case COMMENT:
-			actionLink.append("\">").append(" Open Post").append("</a>");
-			break;
 		case MENTION:
+		case OWN_COMMENT:
 			actionLink.append("\">").append(" Open Post").append("</a>");
 			break;
 		case MESSAGE:
 			actionLink.append("\">").append(" Go to Message").append("</a>");
 			break;
 		case WP_FOLDER_ADDEDUSER:
-			actionLink.append("\">").append(" Go to Folder").append("</a>");
-			break;
 		case WP_FOLDER_REMOVEDUSER:
-			actionLink.append("\">").append(" Go to Folder").append("</a>");
-			break;
+		case WP_FOLDER_RENAMED:
 		case WP_FOLDER_SHARE:
-			actionLink.append("\">").append(" Go to Folder").append("</a>");
-			break;
 		case WP_ITEM_NEW:
-			actionLink.append("\">").append(" Go to Folder").append("</a>");
-			break;
 		case WP_ITEM_DELETE:
-			actionLink.append("\">").append(" Go to Folder").append("</a>");
-			break;
 		case WP_ITEM_UPDATED:
+		case WP_ITEM_RENAMED:
 			actionLink.append("\">").append(" Go to Folder").append("</a>");
 			break;
-		case OWN_COMMENT:
-			actionLink.append("\">").append(" Open Post").append("</a>");
-			break;
 		case POST_ALERT:
 			actionLink.append("\">").append("See this Post").append("</a>");
 			break;
+		case CAT_ITEM_DELETE:
+		case CAT_ITEM_PUBLISHED:
+		case CAT_ITEM_REJECTED:
+		case CAT_ITEM_SUBMITTED:
+		case CAT_ITEM_UPDATED:
+			StringBuilder myLink = new StringBuilder("<br/><br/><a style=\"color:#3B5998; text-decoration:none\" target=\"_blank\" href=\"");
+			myLink.append(notification2Save.getUri()).append("\">").append(" See this on Catalogue").append("</a>");
+			return myLink.toString();
 		case REQUEST_CONNECTION:
 			actionLink.append("\">").append(" Go to Contacts Center").append("</a>");
 			break;
 		case JOB_COMPLETED_NOK:
-			actionLink.append("\">").append(" Go to Application").append("</a>");
+			//actionLink.append("\">").append(" Go to Application").append("</a>");
+			actionLink.append("\">").append("").append("</a>");
 			break;
 		case JOB_COMPLETED_OK:
-			actionLink.append("\">").append(" Go to Application").append("</a>");
+			//actionLink.append("\">").append(" Go to Application").append("</a>");
+			actionLink.append("\">").append("").append("</a>");
 			break;
 		case CALENDAR_ADDED_EVENT:
 			actionLink.append("\">").append(" Go to Calendar").append("</a>");
@@ -364,6 +381,13 @@ public class SocialMailingUtil {
 	private static StringBuffer buildStringFromNode(Node node) {
 		StringBuffer buffer = new StringBuffer();
 
+		if (node instanceof Element) {
+			Element element = (Element) node;
+			if ("a".equals(element.tagName())) {
+				buffer.append(" ");
+			}
+		}
+
 		if (node instanceof TextNode) {
 			TextNode textNode = (TextNode) node;
 			buffer.append(textNode.text().trim());
@@ -376,89 +400,99 @@ public class SocialMailingUtil {
 		if (node instanceof Element) {
 			Element element = (Element) node;
 			String tagName = element.tagName();
+			if ("a".equals(element.tagName())) {
+				buffer.append(" ");
+			}
 			if ("p".equals(tagName) || "br".equals(tagName)) {
 				buffer.append("\n");
 			}
 		}
-
 		return buffer;
 	}
 
 	/**
 	 * Build up a discussion given the feed and its comments. 
 	 * @param notification2Save
-	 * @param feed
+	 * @param post
 	 * @param comments
 	 * @param commentKey if not null, when building the discussion stop at this comment.
 	 * @return an html string representing the discussion
 	 */
-	protected static String buildHtmlDiscussion(Notification notification2Save, Feed feed, List<Comment> comments, String commentKey){
+	protected static String buildHtmlDiscussion(String portalURL, String pathToVRE, Notification notification2Save, Feed post, List<Comment> comments, String commentKey){
 
 		try{
 
-			if(notification2Save.getType().equals(NotificationType.POST_ALERT) || feed == null)
-				return "";
+			if (notification2Save.getType() == NotificationType.COMMENT ||
+					notification2Save.getType() == NotificationType.OWN_COMMENT ||  
+					notification2Save.getType() == NotificationType.LIKE ||
+					notification2Save.getType() == NotificationType.MENTION){
 
-			String htmlPost = "<br />" + "<br />----<p>Original post:</p>";
-			// data formatter
-			Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
+				String htmlPost = "<br />" + "<br />----<p>Original post:</p>";
+				// data formatter
+				Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
 
-			// escape html
-			String feedTextNoHtml = convertHTML2Text(feed.getDescription());
+				// escape html
+				String postTextNoHtml = post.getDescription().replaceAll("&amp;", "&");
+				postTextNoHtml = postTextNoHtml.replaceAll("href=\"/group/", "href=\""+portalURL + "/group/"); //because there is no indication of the portal (for mentions)	
+				postTextNoHtml = postTextNoHtml.replace("href=\"?", "href=\""+portalURL + pathToVRE + "?"); //because there is no indication of the portal	(for hashtags)	
 
-			// build up html post + comments
-			if(notification2Save.getType() == NotificationType.POST_ALERT || (comments.size() == 0 && notification2Save.getType() == NotificationType.MENTION))
-				htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
-						+ "font-style: italic; font-weight:bold\">"
-						+ feed.getFullName() 
-						+ ": " 
-						+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml) 
-						+ "<p style=\"font-family:Lucida Grande,"
-						+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-						+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(feed.getTime()) + "</p>"
-						+"</div>";
-			else
-				htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
-						+ "font-style: italic\">"
-						+ feed.getFullName() 
-						+ ": " 
-						+ (feedTextNoHtml.length() > 30 ? feedTextNoHtml.substring(0, 30) + " ..." : feedTextNoHtml) 
-						+ "<p style=\"font-family:Lucida Grande,"
-						+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-						+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(feed.getTime()) + "</p>"
-						+"</div>";
 
-			if(comments != null)
-				for (int i = 0; i < comments.size(); i++) {
+				// build up html post + comments
+				if(notification2Save.getType() == NotificationType.POST_ALERT || (comments.size() == 0 && notification2Save.getType() == NotificationType.MENTION))
+					htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
+							+ "font-style: italic; font-weight:bold\">"
+							+ post.getFullName() 
+							+ ": " 
+							+ (postTextNoHtml.length() > 200 ? postTextNoHtml.substring(0, 200) + " ..." : postTextNoHtml) 
+							+ "<p style=\"font-family:Lucida Grande,"
+							+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+							+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(post.getTime()) + "</p>"
+							+"</div>";
+				else
+					htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;padding-left: 15px;  "
+							+ "font-style: italic\">"
+							+ post.getFullName() 
+							+ ": " 
+							+ (postTextNoHtml.length() > 200 ? postTextNoHtml.substring(0, 200) + " ..." : postTextNoHtml) 
+							+ "<p style=\"font-family:Lucida Grande,"
+							+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+							+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(post.getTime()) + "</p>"
+							+"</div>";
 
-					String commentTextNoHtml = comments.get(i).getText().replaceAll("&amp;", "&");
+				if(comments != null)
+					for (int i = 0; i < comments.size(); i++) {
 
-					if((commentKey != null && comments.get(i).getKey().equals(commentKey)) && !(notification2Save.getType() == NotificationType.POST_ALERT)){
-						htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
-								+ "border-left: 3px solid #ccc; font-style: italic; font-weight:bold\">"
-								+ comments.get(i).getFullName() 
-								+ ": " 
-								+ commentTextNoHtml 
-								+ "<p style=\"font-family:Lucida Grande,"
-								+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-								+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
-								+"</div>";
+						String commentTextNoHtml = comments.get(i).getText().replaceAll("&amp;", "&");
+						commentTextNoHtml = commentTextNoHtml.replaceAll("href=\"/group/", "href=\""+portalURL + "/group/"); //because there is no indication of the portal (for mentions)	
+						commentTextNoHtml = commentTextNoHtml.replace("href=\"?", "href=\""+portalURL + pathToVRE + "?"); //because there is no indication of the portal	(for hashtags)	
 
-						break;
-					}
-					else
-						htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
-								+ "border-left: 3px solid #ccc; font-style: italic;\">"
-								+ comments.get(i).getFullName() 
-								+ ": " 
-								+ commentTextNoHtml 
-								+ "<p style=\"font-family:Lucida Grande,"
-								+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
-								+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
-								+"</div>";
-				} 
+						if((commentKey != null && comments.get(i).getKey().equals(commentKey)) && !(notification2Save.getType() == NotificationType.POST_ALERT)){
+							htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
+									+ "border-left: 3px solid #ccc; font-style: italic; font-weight:bold\">"
+									+ comments.get(i).getFullName() 
+									+ ": " 
+									+ commentTextNoHtml 
+									+ "<p style=\"font-family:Lucida Grande,"
+									+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+									+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
+									+"</div>";
 
-			return htmlPost;
+							break;
+						}
+						else
+							htmlPost += "<div style=\"margin-top: 10px;  margin-bottom: 10px;  margin-left: 50px;  padding-left: 15px;  "
+									+ "border-left: 3px solid #ccc; font-style: italic;\">"
+									+ comments.get(i).getFullName() 
+									+ ": " 
+									+ commentTextNoHtml 
+									+ "<p style=\"font-family:Lucida Grande,"
+									+ "Verdana,Bitstream Vera Sans,Arial,sans-serif; "
+									+ "white-space: nowrap; font-size: smaller; color: #999;\">" + formatter.format(comments.get(i).getTime()) + "</p>"
+									+"</div>";
+					} 
+				_log.debug("***buildHtmlDiscussion returning=\n"+htmlPost);
+				return htmlPost;
+			}
 		}catch(Exception e){
 			_log.error("Unable to reconstruct html discussion to put into the email body.", e);
 		}
@@ -477,45 +511,48 @@ public class SocialMailingUtil {
 
 		try{
 
-			if(notification2Save.getType().equals(NotificationType.POST_ALERT) || feed == null)
-				return "";
+			if (notification2Save.getType() == NotificationType.COMMENT ||
+					notification2Save.getType() == NotificationType.OWN_COMMENT ||  
+					notification2Save.getType() == NotificationType.LIKE ||
+					notification2Save.getType() == NotificationType.MENTION){
 
-			// build discussion
-			String discussion = "\n\n----\n\nOriginal post:";
+				// build discussion
+				String discussion = "\n\n----\n\nOriginal post:";
 
-			// data formatter
-			Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
+				// data formatter
+				Format formatter = new SimpleDateFormat("yyyy-MM-dd hh:mm a");
 
-			// escape html
-			String feedTextNoHtml = convertHTML2Text(feed.getDescription());
-
-			// build up  post + comments
-			discussion += 
-					"\n"
-							+ "["  + formatter.format(feed.getTime())  + "] " 
-							+ feed.getFullName() 
-							+ ": " 
-							+ (feedTextNoHtml.length() > 200 ? feedTextNoHtml.substring(0, 200) + " ..." : feedTextNoHtml)
-							+ "\n";
-
-
-			for (int i = 0; i < comments.size(); i++) {
-
-				String commentTextNoHtml = convertHTML2Text(comments.get(i).getText());
+				// escape html
+				String feedTextNoHtml = convertHTML2Text(feed.getDescription());
 
+				// build up  post + comments
 				discussion += 
-						"\t"
-								+ "["  + formatter.format(comments.get(i).getTime())  + "] " 
-								+ comments.get(i).getFullName() 
+						"\n"
+								+ "["  + formatter.format(feed.getTime())  + "] " 
+								+ feed.getFullName() 
 								+ ": " 
-								+ commentTextNoHtml 
+								+ (feedTextNoHtml.length() > 200 ? feedTextNoHtml.substring(0, 200) + " ..." : feedTextNoHtml)
 								+ "\n";
 
-				if(commentKey != null && comments.get(i).getKey().equals(commentKey))
-					break;
-			}
 
-			return discussion;
+				for (int i = 0; i < comments.size(); i++) {
+
+					String commentTextNoHtml = convertHTML2Text(comments.get(i).getText());
+
+					discussion += 
+							"\t"
+									+ "["  + formatter.format(comments.get(i).getTime())  + "] " 
+									+ comments.get(i).getFullName() 
+									+ ": " 
+									+ commentTextNoHtml 
+									+ "\n";
+
+					if(commentKey != null && comments.get(i).getKey().equals(commentKey))
+						break;
+				}
+
+				return discussion;
+			}
 		}
 		catch(Exception e){
 			_log.error("Unable to reconstruct plain text discussion to put into the email body.", e);
@@ -523,4 +560,27 @@ public class SocialMailingUtil {
 
 		return "";
 	}
+	/**
+	 * 
+	 * @param gatewayURL
+	 * @param vreName the VRE Name (e.g. AquaMaps)
+	 * @return
+	 */
+	private static String getVREUrl(String gatewayURL, String vreName) {
+		return new StringBuffer(gatewayURL)
+				.append(GCubePortalConstants.PREFIX_GROUP_URL)
+				.append("/").append(vreName.toLowerCase()).toString();
+	}
+	/**
+	 * 
+	 * @param username
+	 * @return
+	 */
+	private static String getUserProfileLink(String username) {
+		return "profile?"+ new String(
+				Base64.getEncoder().encodeToString(GCubePortalConstants.USER_PROFILE_OID.getBytes())+
+				"="+
+				new String( Base64.getEncoder().encodeToString(username.getBytes()) )
+				);
+	}
 }
