@@ -1,6 +1,7 @@
 package org.gcube.vomanagement.usermanagement.exception;
 
 import com.liferay.portal.kernel.exception.PortalException;
+import com.liferay.portal.kernel.exception.SystemException;
 import com.liferay.portal.kernel.log.Log;
 import com.liferay.portal.kernel.log.LogFactoryUtil;
 
@@ -14,4 +15,8 @@ public class GroupRetrievalFault extends Exception {
 	public GroupRetrievalFault(String errorMsg, long groupId , PortalException e){
 		_log.error(errorMsg + ", groupId=" + groupId);
 	}
+	
+	public GroupRetrievalFault(String errorMsg, long groupId , SystemException e){
+		_log.error(errorMsg + ", groupId=" + groupId);
+	}
 }
