@@ -31,13 +31,17 @@ import com.liferay.portal.service.UserGroupRoleLocalServiceUtil;
 import com.liferay.portal.service.UserLocalServiceUtil;
 import com.liferay.portal.util.PortalUtil;
 
+/**
+ * Exploit Liferay JSON Web Service to perform RoleManager's operations.
+ * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
+ */
 public class LiferayRoleManager implements RoleManager {
 	/**
 	 * logger
 	 */
 	private static final Log _log = LogFactoryUtil.getLog(LiferayRoleManager.class);
 	private static final String ADMINISTRATOR = "Administrator";
-	private static final int ROLE_TYPE = 2;  // role type. 1=regular, 2=site, 3=organization 
+	protected static final int ROLE_TYPE = 2;  // role type. 1=regular, 2=site, 3=organization 
 
 	//simple role mapping
 	protected static GCubeRole mapLRRole(Role r) throws PortalException, SystemException {
@@ -323,8 +327,9 @@ public class LiferayRoleManager implements RoleManager {
 		try {
 			roles = RoleLocalServiceUtil.getRoles(ManagementUtils.getCompany().getCompanyId());
 			for (Role role : roles) {
-				if (role.getType()==ROLE_TYPE)
+				if (role.getType()==ROLE_TYPE && !role.getName().startsWith("Site")) {
 					toReturn.add(mapLRRole(role));
+				}
 			}
 		} catch (SystemException | PortalException e) {
 			e.printStackTrace();
@@ -340,7 +345,7 @@ public class LiferayRoleManager implements RoleManager {
 		try {
 			List<UserGroupRole> roles = UserGroupRoleLocalServiceUtil.getUserGroupRolesByGroup(groupId);
 			for (UserGroupRole ugr : roles) {
-				if (ugr.getUserId()==userId)
+				if (ugr.getUserId()==userId && !ugr.getRole().getName().startsWith("Site"))
 					toReturn.add(mapLRRole(ugr.getRole()));
 			}
 		} catch (SystemException e) {
