@@ -29,6 +29,9 @@ import org.gcube.vomanagement.usermanagement.model.GatewayRolesNames;
 import org.gcube.vomanagement.usermanagement.model.MembershipRequestStatus;
 import org.gcube.vomanagement.usermanagement.util.ManagementUtils;
 
+import com.liferay.portal.kernel.dao.orm.DynamicQuery;
+import com.liferay.portal.kernel.dao.orm.DynamicQueryFactoryUtil;
+import com.liferay.portal.kernel.dao.orm.PropertyFactoryUtil;
 import com.liferay.portal.kernel.dao.orm.QueryUtil;
 import com.liferay.portal.kernel.exception.PortalException;
 import com.liferay.portal.kernel.exception.SystemException;
@@ -38,6 +41,7 @@ import com.liferay.portal.kernel.util.DigesterUtil;
 import com.liferay.portal.kernel.util.HttpUtil;
 import com.liferay.portal.kernel.util.OrderByComparator;
 import com.liferay.portal.kernel.util.OrderByComparatorFactoryUtil;
+import com.liferay.portal.kernel.util.PortalClassLoaderUtil;
 import com.liferay.portal.model.Contact;
 import com.liferay.portal.model.EmailAddress;
 import com.liferay.portal.model.Group;
@@ -878,10 +882,63 @@ public class LiferayUserManager implements UserManager {
 		} catch (SystemException e) {
 			e.printStackTrace();
 		} 
+		DynamicQuery queryListPendingMembershipRequestsByGroup = DynamicQueryFactoryUtil.forClass
+				(MembershipRequest.class, PortalClassLoaderUtil.getClassLoader());
+		
+		queryListPendingMembershipRequestsByGroup.add(PropertyFactoryUtil.forName("groupId").eq(new Long(groupId)));
+		
 		List<GCubeMembershipRequest> toReturn = new ArrayList<GCubeMembershipRequest>();
 		try {
-			int requestesNo = MembershipRequestLocalServiceUtil.getMembershipRequestsCount();
-			for (MembershipRequest req : MembershipRequestLocalServiceUtil.getMembershipRequests(0, requestesNo)) {
+			
+			@SuppressWarnings("unchecked")
+			List<MembershipRequest> list = MembershipRequestLocalServiceUtil.dynamicQuery(queryListPendingMembershipRequestsByGroup);
+			for (MembershipRequest req : list) {
+				if (req.getGroupId() == groupId) {
+					try {
+						toReturn.add(mapLRMembershipRequest(req));
+					} catch (com.liferay.portal.NoSuchUserException e) {
+						_log.warn("Could not map membership request, userid no longer exists: "+req.getUserId());
+					}
+				}
+			}
+
+		} catch (SystemException e) {
+			e.printStackTrace();
+		} catch (PortalException e) {
+			e.printStackTrace();
+		}
+		return toReturn;
+	}
+	/*
+	 * MEMBERSHIP REQUESTS
+	 */
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public List<GCubeMembershipRequest> listPendingMembershipRequestsByGroup(long groupId) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault {
+		try {
+			Group g = GroupLocalServiceUtil.getGroup(groupId);
+			_log.debug("Asked for pending users list of group: "+g.getName());
+		} catch (PortalException e1) {
+			throw new GroupRetrievalFault("Group not existing", groupId, e1);
+		} catch (SystemException e) {
+			e.printStackTrace();
+		} 
+	
+		
+		DynamicQuery queryListPendingMembershipRequestsByGroup = DynamicQueryFactoryUtil.forClass
+				(MembershipRequest.class, PortalClassLoaderUtil.getClassLoader());
+		
+		queryListPendingMembershipRequestsByGroup.add(PropertyFactoryUtil.forName("statusId").eq(new Integer ("2")));
+		queryListPendingMembershipRequestsByGroup.add(PropertyFactoryUtil.forName("groupId").eq(new Long(groupId)));
+		
+		List<GCubeMembershipRequest> toReturn = new ArrayList<GCubeMembershipRequest>();
+		try {
+			
+			@SuppressWarnings("unchecked")
+			List<MembershipRequest> list = MembershipRequestLocalServiceUtil.dynamicQuery(queryListPendingMembershipRequestsByGroup);
+			for (MembershipRequest req : list) {
 				if (req.getGroupId() == groupId) {
 					toReturn.add(mapLRMembershipRequest(req));
 				}
@@ -916,16 +973,17 @@ public class LiferayUserManager implements UserManager {
 	public GCubeMembershipRequest acceptMembershipRequest(long requestUserId,long groupId, boolean addUserToGroup, String replyUsername, String replyComment) throws UserManagementSystemException, GroupRetrievalFault, UserManagementPortalException {
 		try {
 			GCubeUser replyMan = getUserByUsername(replyUsername);
-			List<GCubeMembershipRequest> requests = listMembershipRequestsByGroup(groupId);
-			for (GCubeMembershipRequest req : requests) {
-				if (req.getRequestingUser().getUserId() == requestUserId) {
+			List<MembershipRequest> requests = MembershipRequestLocalServiceUtil.getMembershipRequests(requestUserId, groupId, 0);
+			//List<GCubeMembershipRequest> requests = listMembershipRequestsByGroup(groupId);
+			for (MembershipRequest req : requests) {
+				if (req.getUserId() == requestUserId) {
 					MembershipRequestLocalServiceUtil.updateStatus(replyMan.getUserId(), req.getMembershipRequestId(), replyComment, 1, addUserToGroup, new ServiceContext());
 					//the method above just adds the user to the VRE, it is needed to add the user to the parent Sites as well (VO and RootVO)
 					assignUserToGroup(GroupLocalServiceUtil.getGroup(groupId).getParentGroupId(), requestUserId); 
-
+					_log.info("Accepted membership request: requestUserId="+requestUserId);
 					return mapLRMembershipRequest(MembershipRequestLocalServiceUtil.getMembershipRequest(req.getMembershipRequestId()));
 				}
-			}
+			}			
 
 		} catch (UserRetrievalFault e) {
 			e.printStackTrace();
